==> OpenFisca_France_Dotations_Locales-0.7.5-py3-none-any.whl: OpenFisca_France_Dotations_Locales-0.7.5.data/data/share/openfisca/openfisca-france-dotations-locales/REFERENCES.md <==

# Références législatives

* [Code général des collectivités territoriales](https://www.legifrance.gouv.fr/affichCode.do?cidTexte=LEGITEXT000006070633)
* [Toutes notes dotations de la DGCL](http://www.dotations-dgcl.interieur.gouv.fr/consultation/informations_repartition.php)

## Dotation forfaitaire (DF)

* [collectivites-locales.gouv.fr, DF 2019](https://www.collectivites-locales.gouv.fr/files/files/dgcl_v2/FLAE_circulaires_10_fevrier2016/note_dinformation_2019_dfcom_-_vdef2.pdf)

* Note DGCL, [DF 2020](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=115)

> Documents complémentaires pouvant servir à la compréhension des mécanismes de calcul :
> * [Rapport du Gouvernement au Parlement, Historique et analyse des effets de l’introduction d’un coefficient logarithmique](https://www.banquedesterritoires.fr/sites/default/files/2019-12/Coefficient%20logarithmique%20-%20Rapport%20global%20%282%29.pdf)
> * [collectivites-locales.gouv.fr, DF 2015](https://www.collectivites-locales.gouv.fr/files/files/noteinfo_dotationforfaitairecommunes.pdf)
> * [amf.asso.fr, DF 2016](http://medias.amf.asso.fr/docs/DOCUMENTS/AMF_14463_NOTE.pdf)
> * [yvelines.gouv.fr, DF 2018](http://www.yvelines.gouv.fr/content/download/15362/97278/file/Annexe%20de%20calcul-2018%20Dotation%20forfaitaire.pdf)

## Dotation d'aménagement

### Dotation de Solidarité Rurale (DSR)

* Note DGCL, [DSR 2019](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=94)

### Dotation de Solidarité Urbaine et de cohésion sociale (DSU)

* Note DGCL, [DSU 2020](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=120)
* Note DGCL, [DSU 2019](https://www.collectivites-locales.gouv.fr/sites/default/files/migration/note_dinformation_2019_dsu.pdf)

## Sources des données

* [data/2019-communes-criteres-repartition.csv](https://www.data.gouv.fr/fr/datasets/criteres-de-repartition-des-dotations-versees-par-letat-aux-collectivites-territoriales/)

==> OpenFisca_France_Dotations_Locales-0.8.0-py3-none-any.whl: OpenFisca_France_Dotations_Locales-0.8.0.data/data/share/openfisca/openfisca-france-dotations-locales/REFERENCES.md <==

# Références législatives

* [Code général des collectivités territoriales](https://www.legifrance.gouv.fr/affichCode.do?cidTexte=LEGITEXT000006070633)
* [Toutes notes dotations de la DGCL](http://www.dotations-dgcl.interieur.gouv.fr/consultation/informations_repartition.php)

## Dotation forfaitaire (DF)

* [collectivites-locales.gouv.fr, DF 2019](https://www.collectivites-locales.gouv.fr/files/files/dgcl_v2/FLAE_circulaires_10_fevrier2016/note_dinformation_2019_dfcom_-_vdef2.pdf)

* Note DGCL, DF 2022 (en attente de publication ; dernière vérification au 22 juillet 2022)
* Note DGCL, [DF 2021](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=142)
* Note DGCL, [DF 2020](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=115)
* Note DGCL, [DF 2019](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=92)

> Documents complémentaires pouvant servir à la compréhension des mécanismes de calcul :
> * [Rapport du Gouvernement au Parlement, Historique et analyse des effets de l’introduction d’un coefficient logarithmique](https://www.banquedesterritoires.fr/sites/default/files/2019-12/Coefficient%20logarithmique%20-%20Rapport%20global%20%282%29.pdf)
> * [collectivites-locales.gouv.fr, DF 2015](https://www.collectivites-locales.gouv.fr/files/files/noteinfo_dotationforfaitairecommunes.pdf)
> * [amf.asso.fr, DF 2016](http://medias.amf.asso.fr/docs/DOCUMENTS/AMF_14463_NOTE.pdf)
> * [yvelines.gouv.fr, DF 2018](http://www.yvelines.gouv.fr/content/download/15362/97278/file/Annexe%20de%20calcul-2018%20Dotation%20forfaitaire.pdf)

## Dotation d'aménagement

### Dotation de Solidarité Rurale (DSR)

* Note DGCL, [DSR 2022](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=181)
* Note DGCL, [DSR 2021](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=145)
* Note DGCL, [DSR 2020](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=123)
* Note DGCL, [DSR 2019](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=94)

### Dotation de Solidarité Urbaine et de cohésion sociale (DSU)

* Note DGCL, [DSU 2022](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=179)
* Note DGCL, [DSU 2021](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=140)
* Note DGCL, [DSU 2020](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=120)
* Note DGCL, [DSU 2019](http://www.dotations-dgcl.interieur.gouv.fr/consultation/documentAffichage.php?id=93)

## Sources des données

* [data/2019-communes-criteres-repartition.csv](https://www.data.gouv.fr/fr/datasets/criteres-de-repartition-des-dotations-versees-par-letat-aux-collectivites-territoriales/)
